==> haskell-adjunctions-4.4.3-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.3
visibility:           public
id:                   adjunctions-4.4.3-IxdEz7K533XCxUk7GIWj4F
key:                  adjunctions-4.4.3-IxdEz7K533XCxUk7GIWj4F
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  0f7cd5c5fbe182c3ef33dc17427d9923
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.3-IxdEz7K533XCxUk7GIWj4F
depends:
    array-0.5.4.0 base-4.17.2.1 comonad-5.0.9-GXyCbFymWb23XyPEyPH8Oo
    containers-0.6.7 contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-CDzazwejFtCGl60oBvo2SN
    free-5.2-6qH0BV7uWBY9WRPbhnTBW1 mtl-2.2.2
    profunctors-5.6.3-LgeRiRAoZIJ3q2a53AXjzp
    semigroupoids-6.0.1-1gh8OSweUHoBPxrzLKEmMu
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4.3-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 adjunctions
version:              4.4.3
visibility:           public
id:                   adjunctions-4.4.3-CWPzZdQa1wnG9760TTwsJr
key:                  adjunctions-4.4.3-CWPzZdQa1wnG9760TTwsJr
license:              BSD-2-Clause
copyright:            Copyright (C) 2011-2014 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/adjunctions/
synopsis:             Adjunctions and representable functors
description:          Adjunctions and representable functors.
category:             Data Structures, Adjunctions
abi:                  cbf8d79f988a241998b633ac5019e06f
exposed:              True
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep

import-dirs:          /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/adjunctions-4.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-adjunctions
hs-libraries:         HSadjunctions-4.4.3-CWPzZdQa1wnG9760TTwsJr
depends:
    array-0.5.4.0 base-4.17.2.1 comonad-5.0.9-Ii5hgdheJL2Zm3d3qSYJo
    containers-0.6.7 contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    distributive-0.6.2.1-59IAOHM1chG6SQlfccy7lE
    free-5.2-CXVwhCAINJo3dyg8cgC0kA mtl-2.2.2
    profunctors-5.6.3-JPsyxucHO7GE5uSKcotJO6
    semigroupoids-6.0.1-CiyJpZ8oNNEK3LiWeue5
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html:         /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
